summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libbsp/arm/edb7312
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:07:58 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-31 16:07:58 +0000
commit35f52a69829e2a1e3180949ca38592d2b13034de (patch)
tree30d9b664d846d95d42d7f86d17ddf0c0bd6e4744 /c/src/lib/libbsp/arm/edb7312
parent2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com> (diff)
downloadrtems-35f52a69829e2a1e3180949ca38592d2b13034de.tar.bz2
2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
* timer/timer.c: Rename timer driver methods to follow RTEMS programming conventions.
Diffstat (limited to 'c/src/lib/libbsp/arm/edb7312')
-rw-r--r--c/src/lib/libbsp/arm/edb7312/ChangeLog5
-rw-r--r--c/src/lib/libbsp/arm/edb7312/timer/timer.c20
2 files changed, 15 insertions, 10 deletions
diff --git a/c/src/lib/libbsp/arm/edb7312/ChangeLog b/c/src/lib/libbsp/arm/edb7312/ChangeLog
index 283e422112..1761427e61 100644
--- a/c/src/lib/libbsp/arm/edb7312/ChangeLog
+++ b/c/src/lib/libbsp/arm/edb7312/ChangeLog
@@ -1,3 +1,8 @@
+2008-08-31 Joel Sherrill <joel.sherrill@oarcorp.com>
+
+ * timer/timer.c: Rename timer driver methods to follow RTEMS
+ programming conventions.
+
2008-08-27 Ralf Corsépius <ralf.corsepius@rtems.org>
* timer/timer.c: Eliminate rtems_boolean.
diff --git a/c/src/lib/libbsp/arm/edb7312/timer/timer.c b/c/src/lib/libbsp/arm/edb7312/timer/timer.c
index 0228716c1a..d66d181bca 100644
--- a/c/src/lib/libbsp/arm/edb7312/timer/timer.c
+++ b/c/src/lib/libbsp/arm/edb7312/timer/timer.c
@@ -11,8 +11,8 @@
* Notes:
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
* Timer_initialize() and Read_timer(). Read_timer() usually returns
* the number of microseconds since Timer_initialize() exitted.
*
* It is important that the timer start/stop overhead be determined
* when porting or modifying this code.
@@ -25,16 +25,16 @@
#include <ep7312.h>
uint16_t tstart;
-bool Timer_driver_Find_average_overhead;
+bool benchmark_timerfind_average_overhead;
-void Timer_initialize( void )
+void benchmark_timerinitialize( void )
{
*EP7312_SYSCON1 |= EP7312_SYSCON1_TC2_512KHZ;
*EP7312_TC2D = 0xffff;
}
/*
* The following controls the behavior of Read_timer().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It
* is usually deducted from the number returned.
@@ -48,7 +48,7 @@ void Timer_initialize( void )
/* This value is in microseconds. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-int Read_timer( void )
+int benchmark_timerread( void )
{
uint16_t t;
uint32_t total;
@@ -62,7 +62,7 @@ int Read_timer( void )
total = (uint32_t)0x0000ffff - t; /* result is 1/512000 = ~2 uS */
total = (total * 1953) / 1000; /* convert to uS */
- if ( Timer_driver_Find_average_overhead == 1 )
+ if ( benchmark_timerfind_average_overhead == 1 )
return total; /* in XXX microsecond units */
else {
if ( total < LEAST_VALID )
@@ -79,14 +79,14 @@ int Read_timer( void )
* in Timing Test Suite.
*/
-rtems_status_code Empty_function( void )
+rtems_status_code benchmark_timerempty_function( void )
{
return RTEMS_SUCCESSFUL;
}
-void Set_find_average_overhead(
+void benchmark_timerdisable_subtracting_average_overhead(
bool find_flag
)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timerfind_average_overhead = find_flag;
}
@@ -11,8 +11,8 @@
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
- * Timer_initialize() and Read_timer(). Read_timer() usually returns
- * the number of microseconds since Timer_initialize() exitted.
+ * benchmark_timerinitialize() and benchmark_timerread(). benchmark_timerread() usually returns
+ * the number of microseconds since benchmark_timerinitialize() exitted.
*
* It is important that the timer start/stop overhead be determined
@@ -25,16 +25,16 @@
}
/*
- * The following controls the behavior of Read_timer().
+ * The following controls the behavior of benchmark_timerread().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It